@@ -1,5 +1,5 @@
 package Facebook::Graph::AccessToken;
-$Facebook::Graph::AccessToken::VERSION = '1.1000';
+$Facebook::Graph::AccessToken::VERSION = '1.1100';
 use Moo;
 use Facebook::Graph::AccessToken::Response;
 use Facebook::Graph::Request;
@@ -66,7 +66,7 @@ sub uri_as_string {
 sub request {
     my ($self) = @_;
     return Facebook::Graph::AccessToken::Response->new(
-        response => Facebook::Graph::Request->new->get($self->uri_as_string)->recv->response
+        response => Facebook::Graph::Request->new->get($self->uri_as_string)->response
     );
 }
 
@@ -79,7 +79,7 @@ Facebook::Graph::AccessToken - Acquire an access token from Facebook.
 
 =head1 VERSION
 
-version 1.1000
+version 1.1100
 
 =head1 SYNOPSIS
 
