@@ -1,5 +1,5 @@
 package Facebook::Graph::BatchRequests;
-$Facebook::Graph::BatchRequests::VERSION = '1.1000';
+$Facebook::Graph::BatchRequests::VERSION = '1.1100';
 use Moo;
 use Ouch;
 use Facebook::Graph::Request;
@@ -40,7 +40,7 @@ sub request {
     $self->requests([]); # reset
 
     my $uri = "https://graph.facebook.com";
-    my $resp = Facebook::Graph::Request->new->post($uri, $post)->recv->response;
+    my $resp = Facebook::Graph::Request->new->post($uri, $post)->response;
     
     unless ($resp->is_success) {
         my $message = $resp->message;
@@ -64,7 +64,7 @@ Facebook::Graph::BatchRequests - Batch Requests
 
 =head1 VERSION
 
-version 1.1000
+version 1.1100
 
 =head1 SYNOPSIS
 
