@@ -1,9 +1,9 @@
 package Facebook::Graph::Publish;
-$Facebook::Graph::Publish::VERSION = '1.1000';
+$Facebook::Graph::Publish::VERSION = '1.1100';
 use Moo;
 use Facebook::Graph::Request;
 with 'Facebook::Graph::Role::Uri';
-use AnyEvent::HTTP::LWP::UserAgent;
+use LWP::UserAgent;
 use URI::Escape;
 
 has secret => (
@@ -41,7 +41,7 @@ sub publish {
     my ($self) = @_;
     my $uri = $self->uri;
     $uri->path($self->generate_versioned_path($self->object_name.$self->object_path));
-    return Facebook::Graph::Request->new->post($uri, $self->get_post_params)->recv;
+    return Facebook::Graph::Request->new->post($uri, $self->get_post_params);
 }
 
 1;
@@ -52,7 +52,7 @@ Facebook::Graph::Publish - A base class for publishing various things to faceboo
 
 =head1 VERSION
 
-version 1.1000
+version 1.1100
 
 =head1 DESCRIPTION
 
