@@ -1,5 +1,5 @@
 package Facebook::Graph::Query;
-$Facebook::Graph::Query::VERSION = '1.1000';
+$Facebook::Graph::Query::VERSION = '1.1100';
 use Moo;
 use Facebook::Graph::Request;
 with 'Facebook::Graph::Role::Uri';
@@ -193,7 +193,7 @@ sub uri_as_string {
 
 sub request {
     my ($self) = @_;
-    return Facebook::Graph::Request->new->get($self->uri_as_string)->recv;
+    return Facebook::Graph::Request->new->get($self->uri_as_string);
 }
 
 1;
@@ -204,7 +204,7 @@ Facebook::Graph::Query - Simple and fast searching and fetching of Facebook data
 
 =head1 VERSION
 
-version 1.1000
+version 1.1100
 
 =head1 SYNOPSIS
 
