@@ -1,5 +1,5 @@
 package Facebook::Graph::Session;
-$Facebook::Graph::Session::VERSION = '1.1000';
+$Facebook::Graph::Session::VERSION = '1.1100';
 use Moo;
 use Facebook::Graph::Request;
 with 'Facebook::Graph::Role::Uri';
@@ -34,7 +34,7 @@ sub uri_as_string {
 
 sub request {
     my ($self) = @_;
-    return Facebook::Graph::Request->new->get($self->uri_as_string)->recv;
+    return Facebook::Graph::Request->new->get($self->uri_as_string);
 }
 
 1;
@@ -46,7 +46,7 @@ Facebook::Graph::Session - Convert old API sessions into Graph API access_tokens
 
 =head1 VERSION
 
-version 1.1000
+version 1.1100
 
 =head1 SYNOPSIS
 
